@@ -31,7 +31,7 @@ use strict;
 # Build updates this
 #
 use constant {
-    VERSION => '4.6.13.3'
+    VERSION => '5.0.8.2'
 };
 
 my %params;
@@ -102,15 +102,17 @@ if ( defined $vendor ) {
 	die qq("ERROR: $vendor" is not a recognized host type);
     } elsif ( $vendor eq 'default' ) {
 	$params{HOST} = $vendor = 'linux';
+    } elsif ( $vendor =~ /^debian\./ ) {
+	$params{HOST} = $vendor = 'debian';
     }
 } else {
     if ( -f '/etc/debian_version' ) {
 	$vendor = 'debian';
 	if ( -l '/sbin/init' ) {
-	    if ( readlink '/sbin/init' =~ /systemd/ ) {
-		$rcfilename = 'debian.systemd';
+	    if ( readlink( '/sbin/init' ) =~ /systemd/ ) {
+		$rcfilename = 'shorewallrc.debian.systemd';
 	    } else {
-	$rcfilename = 'shorewallrc.debian.sysvinit';
+		$rcfilename = 'shorewallrc.debian.sysvinit';
 	    }
 	} else {
 	    $rcfilename = 'shorewallrc.debian.sysvinit';
